<?php
/*------------------------------------------------------------------------
# "Hot Elastic Slider" Joomla module
# Copyright (C) 2021 HotThemes. All Rights Reserved.
# License: http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
# Author: HotThemes
# Website: https://www.hotjoomlatemplates.com
-------------------------------------------------------------------------*/

defined('_JEXEC') or die('Restricted access'); // no direct access

use Joomla\CMS\Factory;
use Joomla\CMS\HTML\HTMLHelper;

// get the document object
$doc = Factory::getDocument();

// load jQuery
HTMLHelper::_('jquery.framework');

// load scripts
$doc->addScript($mosConfig_live_site.'/modules/mod_hot_elastic_slider/js/jquery.eislideshow.js');
$doc->addScript($mosConfig_live_site.'/modules/mod_hot_elastic_slider/js/jquery.easing.1.3.js');

// add your stylesheet
$doc->addStyleSheet( 'modules/mod_hot_elastic_slider/tmpl/style.css' );

$doc->addStyleDeclaration( '

.ei-slider {
    height: '.$moduleHeight.';
}

.ei-title {
    left: '.$textAreaLeft.';
    bottom: '.$textAreaBottom.';
    padding: '.$textAreaPadding.';
    max-width:'.$textAreaWidth.';
    background: rgba('.$backgroundColor.','.$backgroundOpacity.');
}

.ei-slider h2, .ei-slider h3, .ei-slider p {
    color: '.$textColor.';
}

.ei-slider h2 {
    font-size: '.$headingSize.';
}

.ei-slider h3 {
    font-size: '.$subHeadingSize.';
}

.ei-slider p {
    font-size: '.$textSize.';
}

a.ei-button, a.ei-button:link, a.ei-button:visited {
    font-size: '.$buttonSize.';
    color: '.$buttonTextColor.';
    background: '.$buttonColor.';
}

.ei-slider-thumbs {
    height: '.$navHeight.';
}

.ei-slider-thumbs li.ei-slider-element{
    background: '.$navBgHover.';
}

.ei-slider-thumbs li a{
    background: '.$navBg.';
    border-left: 1px solid '.$navBgHover.';
}

@media screen and (max-width: 768px) {

    .ei-slider {
        height: '.$moduleHeightTablet.';
    }

}

@media screen and (max-width: 500px) {

    .ei-slider {
        height: '.$moduleHeightPhone.';
    }

}

' );

if (!file_exists(JPATH_BASE.DIRECTORY_SEPARATOR.'media'.DIRECTORY_SEPARATOR.'mod_elastic_slider')) {
    mkdir(JPATH_BASE.DIRECTORY_SEPARATOR.'media'.DIRECTORY_SEPARATOR.'mod_elastic_slider', 0755, true);
}

function make_thumb($src, $dest, $desired_width) {

    /* read the source image */
    $source_image = imagecreatefromjpeg($src);
    $width = imagesx($source_image);
    $height = imagesy($source_image);
    
    /* find the "desired height" of this thumbnail, relative to the desired width  */
    $desired_height = floor($height * ($desired_width / $width));
    
    /* create a new, "virtual" image */
    $virtual_image = imagecreatetruecolor($desired_width, $desired_height);
    
    /* copy source image at a resized size */
    imagecopyresampled($virtual_image, $source_image, 0, 0, 0, 0, $desired_width, $desired_height, $width, $height);
    
    /* create the physical thumbnail image to its destination */
    imagejpeg($virtual_image, $dest);
}

?>

<div class="ei-slider-wrapper">
    <div id="ei-slider" class="ei-slider">
        <ul class="ei-slider-large">
            <?php
            for ($loop = 1; $loop <= 5; $loop += 1) {
                if ($enableSlide[$loop]=="true") {
                    ?>
            <li class="slide<?php echo $loop; ?>">
                <img src="<?php echo $image[$loop][0]; ?>" alt="<?php echo $imageAlt[$loop]; ?>" />
                <?php if($imageHeading[$loop] || $imageSubHeading[$loop] || $imageText[$loop] || $imageTitleArray[$loop]) { ?>
                <div class="ei-title">
                    <?php if($imageHeading[$loop]){ ?><h2><?php echo $imageHeading[$loop]; ?></h2><?php } ?>
                    <?php if($imageSubHeading[$loop]){ ?><h3><?php echo $imageSubHeading[$loop]; ?></h3><?php } ?>
                    <?php if($imageText[$loop]){ ?><p><?php echo $imageText[$loop]; ?></p><?php } ?>
                    <?php if ($imageLinkArray[$loop] && $imageTitleArray[$loop]) { ?>
                    <a class="ei-button" href="<?php echo $imageLinkArray[$loop]; ?>" <?php if ($linkNewWindow) { ?>target="_blank"<?php } ?>><?php echo $imageTitleArray[$loop]; ?></a>
                    <?php } ?>
                </div>
                <?php } ?>
            </li>
            <?php
                }
            }
            ?>
        </ul><!-- ei-slider-large -->
        <ul class="ei-slider-thumbs">
            <li class="ei-slider-element">Current</li>
        <?php
        for ($loop = 1; $loop <= 5; $loop += 1) {
            if ($enableSlide[$loop]=="true") {
                $imagePieces = explode("/", $image[$loop][0]);
                $imagePiecesCount = count($imagePieces);
                $imagePiecesCount--;

                if (!file_exists(JPATH_BASE.DIRECTORY_SEPARATOR.'media'.DIRECTORY_SEPARATOR.'mod_elastic_slider'.DIRECTORY_SEPARATOR.$imagePieces[$imagePiecesCount])) {
                    make_thumb($image[$loop][0], JPATH_BASE.DIRECTORY_SEPARATOR.'media'.DIRECTORY_SEPARATOR.'mod_elastic_slider'.DIRECTORY_SEPARATOR.$imagePieces[$imagePiecesCount], 150);
                }
                ?> 
            <li><a href="#">Slide 1</a><img src="<?php echo $mosConfig_live_site."/media/mod_elastic_slider/".$imagePieces[$imagePiecesCount]; ?>" alt="thumb <?php echo $imageAlt[$loop]; ?>" /></li>
        <?php
            }
        }
        ?>
        </ul><!-- ei-slider-thumbs -->
    </div><!-- ei-slider -->
</div><!-- wrapper -->
<script>
    jQuery(function() {
        jQuery('#ei-slider').eislideshow({
            autoplay            : <?php if ($autoAnimation=="true") { echo "true"; }else{ echo "false"; } ?>,
            slideshow_interval  : <?php echo $pauseTime; ?>,
            easing              : '<?php echo $easing; ?>',
            titleeasing         : '<?php echo $easingTitle; ?>',
            titlespeed          : <?php echo $animSpeed; ?>
        });
    });
</script>